@@ -715,7 +715,16 @@ class Catalog:
 
         return Repository(self, name, self.mini_catalog.getRepository(name))
 
-    def createRepository(self, name, indices=None):
+    def createRepository(
+        self,
+        name,
+        indices=None,
+        vector_store=False,
+        embedder="",
+        api_key="",
+        model="",
+        dimensions=None,
+    ):
         """
         Creates a new repository with the given name.
 
@@ -724,9 +733,27 @@ class Catalog:
         :param indices: If provided, creates a store with the given indices.
                         (e.g. ``["spogi, "gspoi", ...]``)
         :type indices: list[string]
+        :param vector_store: true to create vector store
+        :type vector_store: boolean
+        :param embedder: name of the embedder if vector store
+        :type embedder: string
+        :param api_key: api key if required and vector store
+        :type api_key: string
+        :param dimensions: size of embedding if vector store
+        :type dimensions: integer
         :return: A repository object.
         :rtype: Repository
         """
         return Repository(
-            self, name, self.mini_catalog.createRepository(name, indices=indices)
+            self,
+            name,
+            self.mini_catalog.createRepository(
+                name,
+                indices=indices,
+                vector_store=vector_store,
+                embedder=embedder,
+                api_key=api_key,
+                model=model,
+                dimensions=dimensions,
+            ),
         )
